Index: src/scopes.cc |
diff --git a/src/scopes.cc b/src/scopes.cc |
index 5ad970ad814f1d6ffc06e4b7b04cac57806fa1a8..208dc76ac7a2b15736bbec66a8801a284b842dc4 100644 |
--- a/src/scopes.cc |
+++ b/src/scopes.cc |
@@ -727,8 +727,9 @@ int Scope::ContextChainLength(Scope* scope) { |
for (Scope* s = this; s != scope; s = s->outer_scope_) { |
ASSERT(s != NULL); // scope must be in the scope chain |
if (s->is_with_scope() || s->num_heap_slots() > 0) n++; |
// Catch scopes always have heap slots. |
ASSERT(!s->is_catch_scope() || s->num_heap_slots() > 0); |
+ ASSERT(!s->is_module_scope() || s->num_heap_slots() > 0); |
} |
return n; |
} |
@@ -727,8 +727,9 @@ int Scope::ContextChainLength(Scope* scope) { |
ASSERT(s != NULL); // scope must be in the scope chain |
if (s->is_with_scope() || s->num_heap_slots() > 0) n++; |
- // Catch scopes always have heap slots. |
+ // Catch and module scopes always have heap slots. |
ASSERT(!s->is_catch_scope() || s->num_heap_slots() > 0); |